#!/bin/bash

export PATH=$PATH:/sbin

create_directory() {
    local dir_path="$1"
    # 检查文件夹是否存在
    if [ ! -d "$dir_path" ]; then
        mkdir -p "$dir_path"
    fi
}

move_file() {
    source_path=$1
    target_path=$2
    # 检查源文件或目录是否存在
    if [ ! -e "$source_path" ]; then
        echo "$source_path not exist, no move file."
        return
    fi
    # 分离目标路径的目录部分
    if [ -f "$target_path" ]; then
        echo this is a file
        target_dir=$(dirname "$target_path")
    else
        target_dir=$target_path
    fi
    
    # 检查目标目录是否存在，如果不存在则创建
    if [ ! -d "$target_dir" ]; then
        mkdir -p "$target_dir"
        echo "$target_dir not exist, have created the directory."
    fi
    
    # 执行mv操作
    mv $source_path $target_path
    echo $source_path move to $target_path
}

copy_file() {
    # 功能：复制文件或目录到指定位置，自动创建目标目录
    # 参数：$1 源文件或目录路径，$2 目标路径
    local source_path=$1
    local target_path=$2

    # 检查源文件或目录是否存在
    if [ ! -e "$source_path" ]; then
        echo "$source_path not exist, no copy action taken."
        return 1
    fi

    # 确保目标路径以 / 结尾，如果不是目录则取其目录部分
    local last_char=$(echo "$target_path" | awk '{sub(/ *$/,""); print substr($0,length)}')
    if [ "$last_char" == "/" ]; then
        target_dir=$target_path
    else
        if [ -d "$target_path" ]; then
            target_dir=$target_path
        else
            target_dir=$(dirname "$target_path")
        fi
    fi
    echo "target_dir: $target_dir"

    # 创建目标目录（如果需要）
    if [ ! -d "$target_dir" ]; then
        mkdir -p "$target_dir" && echo "Directory $target_dir not found, created."
    fi

    # 复制操作，根据源路径是否为目录决定是否使用-r
    if [ -d "$source_path" ]; then
        cp -rpf "$source_path" "$target_path"
    else
        cp -pf "$source_path" "$target_path"
    fi

    # 检查复制操作是否成功
    if [ $? -eq 0 ]; then
        echo "$source_path copied to $target_path successfully."
        return 0
    else
        echo "Error occurred while copying $source_path to $target_path."
        return 1
    fi
}

update_initrd() {
    VKERNEL=$(uname -r)
    # Array of available initrd creation commands
    commands="update-initramfs dracut mkinitrd"

    for cmd in $commands; do
        if [ -n "$cmd" ] && command -v "$cmd" >/dev/null 2>&1; then
            case "$cmd" in
                update-initramfs)
                    "$cmd" -u -k "$VKERNEL"
                    ;;
                dracut)
                    "$cmd" -f "/boot/initrd.img-$VKERNEL" "$VKERNEL"
                    ;;
                *)
                    # For any other initrd tool
                    "$cmd" -f "/boot/initrd.img-$VKERNEL" "$VKERNEL"
                    ;;
            esac
            return
        fi
    done

    # If none of the commands are found, print a message
    echo "No suitable initrd creation command found. Initrd not updated."
}

# 软件安装路径
BASE_DIR=/usr/share/loongnix-kde-theme

# sddm配置文件路径
SDDM_CONFIG_FILE="/etc/sddm.conf.d/kde_settings.conf"

# icon 主题安装
if which update-icon-caches >/dev/null 2>&1 ; then
    update-icon-caches /usr/share/icons/loongnix
fi

# 修改sddm配置文件
if [ -f "$SDDM_CONFIG_FILE" ]; then 
    kwriteconfig5 --file $SDDM_CONFIG_FILE --group Theme --key Current Loongnix
    kwriteconfig5 --file $SDDM_CONFIG_FILE --group General --key Theme Loongnix
else
    copy_file $BASE_DIR/sddm.conf.d/kde_settings.conf /etc/sddm.conf.d/
fi

# 切换plymouth主题
plymouth-set-default-theme loongnix
# Array of available initrd creation commands
update_initrd
